@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Copyright (C) 2008-2009 Adam Olsen 
+# Copyright (C) 2008-2010 Adam Olsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,7 +15,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-import sys, os, os.path
+import os
+import os.path
+import sys
 
 # allow disabling of pyc generation. Only works on python >= 2.6
 if os.getenv("EXAILE_NO_OPTIMIZE"):
@@ -29,14 +31,9 @@ if sys.platform == 'linux2':
     try:
         import ctypes
         libc = ctypes.CDLL('libc.so.6')
-        libc.prctl(15, 'exaile', 0, 0, 0)
+        libc.prctl(15, 'exaile', 0, 0, 0) # 15 = PR_SET_NAME
     except:
-        try:
-             import dl
-             libc = dl.open('/lib/libc.so.6')
-             libc.call('prctl', 15, 'exaile\0', 0, 0, 0) # 15 is PR_SET_NAME
-        except:
-            pass
+        pass
 
 # Find out the location of exaile's working directory, and insert it to sys.path
 basedir = os.path.dirname(os.path.realpath(__file__))
@@ -46,7 +43,6 @@ if not os.path.exists(os.path.join(basedir, "exaile.py")):
         basedir = cwd
 sys.path.insert(0, basedir)
 
-
 def main():
     from xl import main
     global exaile
