@@ -13,9 +13,9 @@ class JamendoMenu(xlmenu.GenericTrackMenu):
 
     def _create_menu(self):
         self.append_item = self.append('Append to Current', lambda *e:
-            self.on_append_items(), 'gtk-add')
+            self.on_append_items(), gtk.STOCK_ADD)
         self.download_item = self.append('Download to Library', lambda *e:
-            self.on_download(), 'gtk-save')
+            self.on_download(), gtk.STOCK_SAVE)
 
     def on_append_items(self, selected=None):
         self.emit('append-items')
