@@ -1,4 +1,4 @@
-# Copyright (C) 2009 Abhishek Mukherjee <abhishek.mukher.g@gmail.com>
+# Copyright (C) 2009-2010 Abhishek Mukherjee <abhishek.mukher.g@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@ import notifyprefs
 import logging
 import inspect
 import notify_cover
-from xlgui.prefs import widgets
+from xlgui.preferences import widgets
 from xl import event, common, settings
 from xl.nls import gettext as _
 
@@ -39,7 +39,7 @@ class ExaileNotification(object):
         self.exaile = None
 
     def __inner_preference(klass):
-        """Function will make a property for a given subclass of PrefsItem"""
+        """Function will make a property for a given subclass of Preference"""
         def getter(self):
             return settings.get_option(klass.name, klass.default or None)
 
@@ -87,10 +87,9 @@ class ExaileNotification(object):
                               }
 
         notif = pynotify.Notification(summary, body)
-        notif.set_icon_from_pixbuf(notify_cover.get_image_for_track(track,
-                                                 self.exaile,
-                                                 self.resize,
-                                                 ))
+        pixbuf = notify_cover.get_image_for_track(track, self.resize)
+        if pixbuf is not None:
+            notif.set_icon_from_pixbuf(pixbuf)
         # Attach to tray, if that's how we roll
         if ATTACH_COVERS_OPTION_ALLOWED:
             logger.debug("Attaching to tray")
@@ -120,5 +119,5 @@ def enable(exaile):
 def disable(exaile):
     event.remove_callback(EXAILE_NOTIFICATION.on_play, 'playback_track_start')
 
-def get_prefs_pane():
+def get_preferences_pane():
     return notifyprefs
