@@ -1,4 +1,4 @@
-# Copyright (C) 2009 Abhishek Mukherjee <abhishek.mukher.g@gmail.com>
+# Copyright (C) 2009-2010 Abhishek Mukherjee <abhishek.mukher.g@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,19 +16,18 @@
 
 import gtk.gdk
 import logging
-from xl import xdg, cover
+from xl import xdg, covers
 
 logger = logging.getLogger(__name__)
 
-DEFAULT_COVER = xdg.get_data_path('images/nocover.png')
 RESIZE_SIZE = 48
 
-def notifyosd_get_image_for_track(track, exaile, resize=False):
+def notifyosd_get_image_for_track(track, resize=False):
     '''Get a path for a track
 
     '''
     logger.debug("Getting cover for " + str(track))
-    data = exaile.covers.get_cover(track)
+    data = covers.MANAGER.get_cover(track)
     if not data:
-        data = exaile.covers.get_default_cover()
+        data = covers.MANAGER.get_default_cover()
     return data
