@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2009 Adam Olsen
+# Copyright (C) 2008-2010 Adam Olsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,12 +24,13 @@
 # do so. If you do not wish to do so, delete this exception statement
 # from your version.
 
-
 import logging
 import threading
 import time
 
-import gst, gobject
+import pygst
+pygst.require('0.10')
+import gst, gobject, glib
 
 from xl.nls import gettext as _
 from xl import event, settings, common
@@ -75,7 +76,7 @@ class UnifiedPlayer(_base.ExailePlayer):
         # collections are on slower media can increase it to preserve
         # gapless, at the expense of UI lag.
         self.audio_queue.set_property("max-size-time",
-                settings.get_option("player/queue_duration", 100000))
+                settings.get_option("player/queue_duration", 1000000))
 
     def _setup_pipeline(self):
         self.pipe.add(
@@ -175,6 +176,9 @@ class UnifiedPlayer(_base.ExailePlayer):
             else:
                 self.unlink_stream(self.streams[self._current_stream])
 
+        if not playing:
+            event.log_event_sync('playback_reconfigure_bins', self, None)
+
         self.streams[next] = AudioStream("Stream%s"%(next), caps=self.caps)
         self.streams[next].dec.connect("drained", self._on_drained,
                 self.streams[next])
@@ -187,20 +191,20 @@ class UnifiedPlayer(_base.ExailePlayer):
 
         self.pipe.set_state(gst.STATE_PLAYING)
         self.streams[next]._settle_flag = 1
-        gobject.idle_add(self.streams[next].set_state, gst.STATE_PLAYING)
-        gobject.idle_add(self._set_state, self.pipe, gst.STATE_PLAYING)
+        glib.idle_add(self.streams[next].set_state, gst.STATE_PLAYING)
+        glib.idle_add(self._set_state, self.pipe, gst.STATE_PLAYING)
 
         if fading:
             timeout = int(float(duration)/float(100))
             if self.streams[next]:
-                gobject.timeout_add(timeout, self._fade_stream,
+                glib.timeout_add(timeout, self._fade_stream,
                         self.streams[next], 1)
             if self.streams[self._current_stream]:
-                gobject.timeout_add(timeout, self._fade_stream,
+                glib.timeout_add(timeout, self._fade_stream,
                         self.streams[self._current_stream], -1, True)
             if settings.get_option("player/crossfading", False):
                 time = int(track.get_tag_raw("__length")*1000 - duration)
-                gobject.timer_id = gobject.timeout_add(time,
+                glib.timer_id = glib.timeout_add(time,
                         self._start_crossfade)
 
         self._current_stream = next
@@ -231,16 +235,16 @@ class UnifiedPlayer(_base.ExailePlayer):
         if tr is not None:
             self.play(tr, user=False)
         if self._timer_id:
-            gobject.source_remove(self._timer_id)
+            glib.source_remove(self._timer_id)
         if tr is None:
-            self._timer_id = gobject.timeout_add(1000 * \
+            self._timer_id = glib.timeout_add(1000 * \
                     (self.current.get_tag_raw('__length') - self.get_time()),
                     self.stop)
         return False
 
     def _reset_crossfade_timer(self):
         if self._timer_id:
-            gobject.source_remove(self._timer_id)
+            glib.source_remove(self._timer_id)
         if not self.is_playing():
             return
         if not settings.get_option("player/crossfading", False):
@@ -249,9 +253,9 @@ class UnifiedPlayer(_base.ExailePlayer):
         time = int( self.current.get_tag_raw('__length')*1000 - \
                 (self.get_time()*1000 + duration) )
         if time < duration: # start crossfade now, we're late!
-            gobject.idle_add(self._start_crossfade)
+            glib.idle_add(self._start_crossfade)
         else:
-            self._timer_id = gobject.timeout_add(time, self._start_crossfade)
+            self._timer_id = glib.timeout_add(time, self._start_crossfade)
 
     def unlink_stream(self, stream):
         try:
@@ -262,7 +266,7 @@ class UnifiedPlayer(_base.ExailePlayer):
                 self.adder.release_request_pad(pad)
             except TypeError:
                 pass
-            gobject.idle_add(stream.set_state, gst.STATE_NULL)
+            glib.idle_add(stream.set_state, gst.STATE_NULL)
             try:
                 self.pipe.remove(stream)
             except gst.RemoveError:
@@ -502,7 +506,7 @@ class AudioStream(gst.Bin):
             gst.Bin.set_state(self, gst.STATE_NULL)
             event.log_event("stream_settled", self, None)
             return
-        gobject.idle_add(self._settle_state_sub)
+        glib.idle_add(self._settle_state_sub)
 
     @common.threaded
     def _settle_state_sub(self):
