@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2009 Adam Olsen
+# Copyright (C) 2008-2010 Adam Olsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,9 +25,11 @@
 # from your version.
 
 import cgi
+from datetime import datetime, timedelta
 import logging
 import os
 import random
+import time
 import urllib
 import urlparse
 import xml.etree.cElementTree as ETree
@@ -77,7 +79,10 @@ def save_to_m3u(playlist, path):
             leng = round(float(rawlen))
         if not rawlen or leng < 1:
             leng = -1
+        artist = track.get_tag_raw('artist', join=True)
         title = track.get_tag_raw('title', join=True)
+        if artist:
+            title = artist + ' - ' + title
         handle.write("#EXTINF:%d,%s\n%s\n" % (leng,
             title, track.get_loc_for_io()))
 
@@ -126,7 +131,12 @@ def import_from_m3u(path):
                         length = 0
                 else:
                     length = 0
-                current.set_tag_raw('title', title)
+                artist_title = title.split(' - ', 1)
+                if len(artist_title) > 1:
+                    current.set_tag_raw('artist', artist_title[0])
+                    current.set_tag_raw('title', artist_title[1])
+                else:
+                    current.set_tag_raw('title', title)
                 current.set_tag_raw('__length', length)
                 current_extinf = None
 
@@ -149,11 +159,14 @@ def save_to_pls(playlist, path):
     count = 1
 
     for track in playlist:
+        artist = track.get_tag_raw('artist', join=True)
+        title = track.get_tag_raw('title', join=True)
+        if artist:
+            title = artist + ' - ' + title
         handle.write("File%d=%s\n" % (count, track.get_loc_for_io()))
-        handle.write("Title%d=%s\n" % (count,
-                track.get_tag_raw('title', join=True)))
+        handle.write("Title%d=%s\n" % (count, title))
         length = round(float(track.get_tag_raw('__length') or -1))
-        if length < 1:
+        if length < 0:
             length = -1
         handle.write("Length%d=%d\n\n" % (count, length))
         count += 1
@@ -197,17 +210,22 @@ def import_from_pls(path, handle=None):
     pl = Playlist(name=name)
 
     for n in range(1,num+1):
-        tr = trax.Track(linedict["file%s"%n])
-        if "title%s"%n in linedict:
-            tr.set_tag_raw('title', linedict["title%s"%n])
+        tr = trax.Track(linedict["file%d" % n])
+        if ("title%d" % n) in linedict:
+            title = linedict["title%d" % n]
+            artist_title = title.split(' - ', 1)
+            if len(artist_title) > 1:
+                artist, title = artist_title
+                tr.set_tag_raw('artist', artist)
         else:
-            tr.set_tag_raw('title', linedict["file%s"%n].split("/")[-1])
-        if "__length%s"%n in linedict:
-            length = float(linedict["__length%s"%n])
+            title = os.path.splitext(os.path.basename(linedict["file%d" % n]))[0]
+        tr.set_tag_raw('title', title)
+        if ("Length%d" % n) in linedict:
+            length = float(linedict["Length%d" % n])
+            if length < 0:
+                length = 0
         else:
             length = 0
-        if length < 1:
-            length = 0
         tr.set_tag_raw('__length', length)
         pl.add(tr, ignore_missing_files=False)
 
@@ -401,14 +419,15 @@ class Playlist(object):
         self.random_enabled = False
         self.random_mode = "track"
         self.repeat_enabled = False
+        self.repeat_mode = "playlist"
         self.dynamic_enabled = False
         self._is_custom = is_custom
         self._needs_save = False
         self.name = name
         self.tracks_history = []
         self.extra_save_items = ['random_enabled', 'random_mode',
-                'repeat_enabled', 'dynamic_enabled', 'current_pos',
-                'name', '_is_custom', '_needs_save']
+            'repeat_enabled', 'repeat_mode', 'dynamic_enabled',
+            'current_pos', 'name', '_is_custom', '_needs_save']
 
     def get_name(self):
         return self.name
@@ -613,13 +632,18 @@ class Playlist(object):
 
     def peek(self):
         """
-            returns the next track that will be played
+            Returns the next track that will be played
         """
         if self.random_enabled:
             return None #peek() is meaningless with random
-        nextpos = self.current_pos + 1
+
+        if self.repeat_enabled and self.repeat_mode == 'track':
+            nextpos = self.current_pos
+        else:
+            nextpos = self.current_pos + 1
+
         if nextpos >= len(self):
-            if self.repeat_enabled:
+            if self.repeat_enabled and self.repeat_mode == 'playlist':
                 nextpos = 0
             else:
                 return None # end of playlist
@@ -672,8 +696,8 @@ class Playlist(object):
         if self.random_enabled:
             if self.current_pos != -1:
                 self.tracks_history.append(self.get_current())
-                if self.repeat_enabled and len(self.tracks_history) >= \
-                        len(self.ordered_tracks):
+                if self.repeat_enabled and \
+                    len(self.tracks_history) >= len(self.ordered_tracks):
                     self.tracks_history = []
             if len(self.ordered_tracks) == 1 and \
                     len(self.tracks_history) == 1:
@@ -689,14 +713,15 @@ class Playlist(object):
                 self.tracks_history = []
                 return None
             self.current_pos = self.ordered_tracks.index(next)
-
+        elif self.repeat_enabled and self.repeat_mode == 'track':
+            pass # Stay where we are
         else:
             if len(self.ordered_tracks) == 0:
                 return None
             self.current_pos += 1
 
         if self.current_pos >= len(self.ordered_tracks):
-            if self.repeat_enabled:
+            if self.repeat_enabled and self.repeat_mode == 'playlist':
                 self.current_pos = 0
             else:
                 self.current_pos = -1
@@ -722,7 +747,7 @@ class Playlist(object):
         else:
             self.current_pos -= 1
             if self.current_pos < 0:
-                if self.repeat_enabled:
+                if self.repeat_enabled and self.repeat_mode == 'playlist':
                     self.current_pos = len(self.ordered_tracks) - 1
                 else:
                     self.current_pos = 0
@@ -779,7 +804,7 @@ class Playlist(object):
         """
             Enables random mode if it isn't already enabled
 
-            @param value: [bool]
+            :param value: [bool]
         """
         if not self.random_enabled:
             self.tracks_history = []
@@ -790,13 +815,14 @@ class Playlist(object):
             self.random_mode = mode
         self._dirty = True
 
-    def set_repeat(self, value):
+    def set_repeat(self, value, mode="playlist"):
         """
             Enables repeat mode if it isn't already enabled
 
-            @param value: [bool]
+            :param value: [bool]
         """
         self.repeat_enabled = value
+        self.repeat_mode = mode
         self._dirty = True
 
     def set_dynamic(self, value):
@@ -848,7 +874,7 @@ class Playlist(object):
         for item in self.extra_save_items:
             val = getattr(self, item)
             try:
-                strn = settings._SETTINGSMANAGER._val_to_str(val)
+                strn = settings.MANAGER._val_to_str(val)
             except ValueError:
                 strn = ""
 
@@ -878,7 +904,7 @@ class Playlist(object):
             if line == "":
                 break
             item, strn = line[:-1].split("=",1)
-            val = settings._SETTINGSMANAGER._str_to_val(strn)
+            val = settings.MANAGER._str_to_val(strn)
             if hasattr(self, item):
                 setattr(self, item, val)
         f.close()
@@ -1065,9 +1091,7 @@ class SmartPlaylist(object):
 
         search_string = self._create_search_string()
 
-        print search_string
-
-        matcher = trax.TracksMatcher(search_string)
+        matcher = trax.TracksMatcher(search_string, case_sensitive=False)
         trs = [ t.track for t in trax.search_tracks(collection, [matcher]) ]
         if self.random_sort:
             random.shuffle(trs)
@@ -1090,7 +1114,14 @@ class SmartPlaylist(object):
         """
 
         params = [] # parameter list
-        steps = settings.get_option('miscellaneous/rating_steps', 5)
+        maximum = settings.get_option('rating/maximum', 5)
+        durations = {
+            _('seconds'): lambda value: timedelta(seconds=value),
+            _('minutes'): lambda value: timedelta(minutes=value),
+            _('hours'): lambda value: timedelta(hours=value),
+            _('days'): lambda value: timedelta(days=value),
+            _('weeks'): lambda value: timedelta(weeks=value),
+        }
 
         for param in self.search_params:
             if type(param) == str:
@@ -1100,7 +1131,13 @@ class SmartPlaylist(object):
             s = ""
 
             if field == '__rating':
-                value = float((100.0*value)/steps)
+                value = float((100.0*value)/maximum)
+            elif field in ('__date_added', '__last_played'):
+                duration, unit = value
+                delta = durations[unit](duration)
+                point = datetime.now() - delta
+                value = time.mktime(point.timetuple())
+
             if op == ">=" or op == "<=":
                 s += '( %(field)s%(op)s%(value)s ' \
                     '| %(field)s==%(value)s )' % \
