@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2009 Adam Olsen
+# Copyright (C) 2008-2010 Adam Olsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,17 +24,30 @@
 # do so. If you do not wish to do so, delete this exception statement
 # from your version.
 
+import gio
+import glib
 import gobject
 import gtk
 import threading
 
-from xlgui import panel, guiutil, commondialogs, menu
-from xlgui import playlist as guiplaylist
-import xlgui.panel.playlists as playlistpanel
-from xl import xdg, event, common, settings
-import xl.radio
-import xl.playlist
+import xl.radio, xl.playlist
+from xl import (
+    event,
+    common,
+    settings,
+    trax,
+    xdg
+)
 from xl.nls import gettext as _
+import xlgui.panel.playlists as playlistpanel
+from xlgui import (
+    guiutil,
+    icons,
+    menu,
+    panel,
+    playlist as guiplaylist
+)
+from xlgui.widgets import dialogs
 
 class RadioException(Exception): pass
 class ConnectionException(RadioException): pass
@@ -46,6 +59,7 @@ class RadioPanel(panel.Panel, playlistpanel.BasePlaylistPanelMixin):
     __gsignals__ = {
         'playlist-selected': (gobject.SIGNAL_RUN_LAST, None, (object,)),
         'append-items': (gobject.SIGNAL_RUN_LAST, None, (object,)),
+        'replace-items': (gobject.SIGNAL_RUN_LAST, None, (object,)),
         'queue-items': (gobject.SIGNAL_RUN_LAST, None, (object,)),
     }
     ui_info = ('radio_panel.ui', 'RadioPanelWindow')
@@ -135,22 +149,24 @@ class RadioPanel(panel.Panel, playlistpanel.BasePlaylistPanelMixin):
         self.status.set_text(message)
 
         if timeout:
-            gobject.timeout_add_seconds(timeout, self._set_status, '', 0)
+            glib.timeout_add_seconds(timeout, self._set_status, '', 0)
 
     def _connect_events(self):
         """
             Connects events used in this panel
         """
         self.track_menu.connect('remove-track', lambda *e:
-            self.remove_selected_tracks())
+            self.remove_selected_track())
 
         menu = self.playlist_menu
         menu.connect('add-playlist', self._on_add_button_clicked)
 
         menu.connect('append-items', lambda *e:
-            self.emit('append-items', self.get_selected_tracks()))
+            self.emit('append-items', self.tree.get_selected_tracks()))
+        menu.connect('replace-items', lambda *e:
+            self.emit('replace-items', self.tree.get_selected_tracks()))
         menu.connect('queue-items', lambda *e:
-            self.emit('queue-items', self.get_selected_tracks()))
+            self.emit('queue-items', self.tree.get_selected_tracks()))
         menu.connect('open-playlist', lambda *e:
             self.open_selected_playlist())
         menu.connect('export-playlist', lambda widget, path:
@@ -175,11 +191,20 @@ class RadioPanel(panel.Panel, playlistpanel.BasePlaylistPanelMixin):
                 self.manager)
 
     def _on_add_button_clicked(self, *e):
-        dialog = commondialogs.MultiTextEntryDialog(self.parent,
+        dialog = dialogs.MultiTextEntryDialog(self.parent,
             _("Add Radio Station"))
 
         dialog.add_field(_("Name:"))
-        dialog.add_field(_("URL:"))
+        url_field = dialog.add_field(_("URL:"))
+
+        clipboard = gtk.clipboard_get()
+        text = clipboard.wait_for_text()
+
+        if text is not None:
+            location = gio.File(uri=text)
+
+            if location.get_uri_scheme() is not None:
+                url_field.set_text(text)
 
         result = dialog.run()
         dialog.hide()
@@ -217,7 +242,7 @@ class RadioPanel(panel.Panel, playlistpanel.BasePlaylistPanelMixin):
             Sets up the tree that displays the radio panel
         """
         box = self.builder.get_object('RadioPanel')
-        self.tree = guiutil.DragTreeView(self, True, True)
+        self.tree = playlistpanel.PlaylistDragTreeView(self, True, True)
         self.tree.set_headers_visible(False)
 
         self.targets = [('text/uri-list', 0, 0)]
@@ -243,7 +268,8 @@ class RadioPanel(panel.Panel, playlistpanel.BasePlaylistPanelMixin):
             xdg.get_data_path('images/track.png'))
         self.folder = self.tree.render_icon(
             gtk.STOCK_DIRECTORY, gtk.ICON_SIZE_SMALL_TOOLBAR)
-        self.refresh_image = guiutil.get_icon('gtk-refresh')
+        self.refresh_image = icons.MANAGER.pixbuf_from_stock(
+            gtk.STOCK_REFRESH)
 
         self.custom = self.model.append(None, [self.folder, _("Saved Stations"), None])
         self.radio_root = self.model.append(None, [self.folder, _("Radio "
@@ -257,10 +283,11 @@ class RadioPanel(panel.Panel, playlistpanel.BasePlaylistPanelMixin):
         box.pack_start(scroll, True, True)
 
     def on_row_activated(self, tree, path, column):
-        iter = self.model.get_iter(path)
-        item = self.model.get_value(iter, 2)
+        item = self.model[path][2]
         if isinstance(item, xl.radio.RadioItem):
             self.emit('playlist-selected', item.get_playlist())
+        elif isinstance(item, playlistpanel.TrackWrapper):
+            self.emit('playlist-selected', item.playlist)
         elif isinstance(item, xl.playlist.Playlist):
             self.open_station(item)
 
@@ -275,7 +302,7 @@ class RadioPanel(panel.Panel, playlistpanel.BasePlaylistPanelMixin):
             Returns the menu that all radio stations use
         """
         menu = guiutil.Menu()
-        menu.append(_("Refresh"), self.on_reload, 'gtk-refresh')
+        menu.append(_("Refresh"), self.on_reload, gtk.STOCK_REFRESH)
         return menu
 
     def on_key_released(self, widget, event):
@@ -404,7 +431,7 @@ class RadioPanel(panel.Panel, playlistpanel.BasePlaylistPanelMixin):
         #After processing playlist proceed to ask the user for the
         #name of the new playlist to add and add the tracks to it
         if len(tracks) > 0:
-            dialog = commondialogs.TextEntryDialog(
+            dialog = dialogs.TextEntryDialog(
             _("Enter the name you want for your new playlist"),
             _("New Playlist"))
             result = dialog.run()
@@ -424,21 +451,18 @@ class RadioPanel(panel.Panel, playlistpanel.BasePlaylistPanelMixin):
 
     def drag_get_data(self, tv, context, selection_data, info, time):
         """
-            CAlled when the user drags a playlist from the radio panel
+            Called when the user drags a playlist from the radio panel
         """
-        pl = self.get_selected_playlist()
-        if pl:
-            tracks = pl.get_tracks()
-        else:
-            tracks = self.get_selected_tracks()
+        tracks = self.tree.get_selected_tracks()
 
-        if not tracks: return
+        if not tracks:
+            return
 
         for track in tracks:
             guiutil.DragTreeView.dragged_data[track.get_loc_for_io()] = track
 
-        urls = guiutil.get_urls_for(tracks)
-        selection_data.set_uris(urls)
+        uris = trax.util.get_uris_from_tracks(tracks)
+        selection_data.set_uris(uris)
 
     def drag_data_delete(self, *e):
         """
@@ -528,7 +552,7 @@ class RadioPanel(panel.Panel, playlistpanel.BasePlaylistPanelMixin):
                 self._set_status(str(e), 2)
 
         if not lists: return
-        gobject.idle_add(self._done_loading, iter, driver, lists)
+        glib.idle_add(self._done_loading, iter, driver, lists)
 
     def _done_loading(self, iter, object, items):
         """
